pub struct AcquiredFrame {
pub image_index: usize,
pub frame_index: usize,
pub ready: Semaphore,
pub complete: Fence,
pub invalidate_images: bool,
}Expand description
Information necessary to render a frame, from Swapchain::acquire
Fields
image_index: usizeIndex of the image to write to in Swapchain::images.
frame_index: usizeIndex of the frame in flight, for use tracking your own per-frame resources, which may be
accessed immediately after Swapchain::acquire returns.
ready: SemaphoreMust be waited on before accessing the image associated with image_index.
complete: FenceMust be signaled when access to the image associated with image_index and any per-frame
resources associated with frame_index is complete.
invalidate_images: boolSet whenever Swapchain::images has, and Swapchain::extent and Swapchain::format
may have, changed since the last Swapchain::acquire call. Use this to invalidate derived
resources like vk::ImageViews and vk::Framebuffers, taking care not to destroy them
until at least SwapchainOptions::frames_in_flight new frames have been acquired, including this
one.